@@ -15,7 +15,11 @@
 #'   \strong{austin} package} \item{\code{"topicmodels"}}{the "dtm" format as 
 #'   used by the \pkg{topicmodels} package} 
 #'   \item{\code{"lsa"}}{the "textmatrix" format as 
-#'   used by the \pkg{lsa} package} }
+#'   used by the \pkg{lsa} package}
+#'   \item{\code{"data.frame"}}{a data.frame where each feature is a variable} 
+#'   \item{\code{"tripletlist"}}{a named "triplet" format list consisting of 
+#'   \code{document}, \code{feature}, and \code{frequency}} 
+#'   }
 #' @param docvars optional data.frame of document variables used as the
 #'   \code{meta} information in conversion to the \pkg{stm} package format.
 #'   This aids in selecting the document variables only corresponding to the
@@ -34,12 +38,17 @@
 #' # stm package format
 #' stmdfm <- convert(quantdfm, to = "stm")
 #' str(stmdfm)
+#' 
+#' #' # triplet
+#' triplet <- convert(quantdfm, to = "tripletlist")
+#' str(triplet)
+#' 
 #' # illustrate what happens with zero-length documents
 #' quantdfm2 <- dfm(c(punctOnly = "!!!", mycorpus[-1]), verbose = FALSE)
 #' rowSums(quantdfm2)
 #' stmdfm2 <- convert(quantdfm2, to = "stm", docvars = docvars(mycorpus))
 #' str(stmdfm2)
-#'  
+#' 
 #' \dontrun{
 #' # tm's DocumentTermMatrix format
 #' tmdfm <- convert(quantdfm, to = "tm")
@@ -51,9 +60,10 @@
 #' # lda package format
 #' ldadfm <- convert(quantdfm, to = "lda")
 #' str(ldadfm)
+#' 
 #' }
 convert <- function(x, to = c("lda", "tm", "stm", "austin", "topicmodels", 
-                              "lsa", "matrix", "data.frame"), docvars = NULL) {
+                              "lsa", "matrix", "data.frame", "tripletlist"), docvars = NULL) {
     UseMethod("convert")
 }
 
@@ -65,7 +75,7 @@ convert.default <- function(x, ...) {
 #' @noRd
 #' @export
 convert.dfm <- function(x, to = c("lda", "tm", "stm", "austin", "topicmodels", 
-                                  "lsa", "matrix", "data.frame"), 
+                                  "lsa", "matrix", "data.frame", "tripletlist"), 
                         docvars = NULL) {
     x <- as.dfm(x)
     to <- match.arg(to)
@@ -95,9 +105,11 @@ convert.dfm <- function(x, to = c("lda", "tm", "stm", "austin", "topicmodels",
     else if (to == "lsa")
         return(dfm2lsa(x))
     else if (to == "data.frame")
-        return(as.data.frame(x))
+        return(dfm2dataframe(x))
     else if (to == "matrix")
         return(as.matrix(x))
+    else if (to == "tripletlist")
+        return(dfm2tripletlist(x))
     else
         stop("invalid \"to\" format")
         
@@ -340,3 +352,24 @@ dfm2lsa <- function(x) {
     class(result) <- "textmatrix"
     t(result)
 }
+
+dfm2tripletlist <- function(x) {
+    feat <- featnames(x)
+    doc <- docnames(x)
+    x <- as(x, "dgTMatrix")
+    list(
+        document = doc[x@i + 1],
+        feature = feat[x@j + 1],
+        frequency = x@x
+    )
+}
+
+dfm2dataframe <- function(x, row.names = NULL, ..., document = docnames(x),
+                          check.names = FALSE) {
+    if (!(is.character(document) || is.null(document)))
+        stop("document must be character or NULL")
+    df <- data.frame(as.matrix(x), row.names = row.names, 
+                     check.names = check.names)
+    if (!is.null(document)) df <- cbind(document, df, stringsAsFactors = FALSE)
+    df    
+}
