@@ -145,12 +145,11 @@ corpus.character <- function(x, docnames = NULL,
                              docvars = NULL, 
                              metacorpus = NULL, 
                              compress = FALSE, ...) {
-    if (length(addedArgs <- list(...)))
-        warning("Argument", ifelse(length(addedArgs)>1, "s ", " "), 
-                names(addedArgs), " not used.", sep = "")
-
-    x_names <- names(x)
-
+    
+    unused_dots(...)
+    name <- names(x)
+    x[is.na(x)] <- ""
+    
     # convert the dreaded "curly quotes" to ASCII equivalents
     x <- stri_replace_all_fixed(x,
                                 c("\u201C", "\u201D", "\u201F",
@@ -169,11 +168,11 @@ corpus.character <- function(x, docnames = NULL,
     if (!is.null(docnames)) {
         stopifnot(length(docnames) == length(x))
         names(x) <- docnames
-    } else if (is.null(x_names)) {
+    } else if (is.null(name)) {
         names(x) <- paste0(quanteda_options("base_docname"), seq_along(x))
     } else if (is.null(names(x))) {
         # if they previously existed, but got obliterated by a stringi function
-        names(x) <- x_names
+        names(x) <- name
     }
 
     # ensure that docnames are unique
@@ -252,11 +251,7 @@ corpus.character <- function(x, docnames = NULL,
 corpus.data.frame <- function(x, docid_field = "doc_id", text_field = "text",
                               metacorpus = NULL, compress = FALSE, ...) {
 
-    if (length(addedArgs <- list(...)))
-        warning("Argument", ifelse(length(addedArgs)>1, "s ", " "), 
-                names(addedArgs), " not used.", sep = "")
-
-    args <- list(...)
+    unused_dots(...)
 
     # coerce data.frame variants to data.frame - for #1232
     x <- as.data.frame(x)
@@ -271,8 +266,7 @@ corpus.data.frame <- function(x, docid_field = "doc_id", text_field = "text",
             stop("text_field index refers to an invalid column")
         }
     }
-    if ("docvars" %in% names(args))
-        stop("docvars are assigned automatically for data.frames")
+
     if (!text_field %in% names(x))
         stop("column name ", text_field, " not found")
     if (!is.character(x[[text_field]]))
@@ -321,27 +315,57 @@ corpus.data.frame <- function(x, docid_field = "doc_id", text_field = "text",
 
 
 #' @rdname corpus
-#' @keywords corpus
+#' @param split_context logical; if \code{TRUE}, split each kwic row into two
+#'   "documents", one for "pre" and one for "post", with this designation saved
+#'   in a new docvar \code{context} and with the new number of documents
+#'   therefore being twice the number of rows in the kwic.
+#' @param extract_keyword logical; if  \code{TRUE}, save the keyword matching
+#'   \code{pattern} as a new docvar \code{keyword}
+#' @examples 
+#' # from a kwic
+#' kw <- kwic(data_char_sampletext, "econom*")
+#' summary(corpus(kw))
+#' summary(corpus(kw, split_context = FALSE))
+#' texts(corpus(kw, split_context = FALSE))
+#' 
 #' @export
-corpus.kwic <- function(x, ...) {
-    if (length(addedArgs <- list(...)))
-        warning("Argument", ifelse(length(addedArgs)>1, "s ", " "), 
-                names(addedArgs), " not used.", sep = "")
+corpus.kwic <- function(x, split_context = TRUE, extract_keyword = TRUE, ...) {
 
+    unused_dots(...)
     class(x) <- "data.frame"
 
     # convert docnames to a factor, as in original kwic
     x$docname <- factor(x$docname)
 
-    pre <- corpus(x[,c("docname", "from", "to", "pre", "keyword")], text_field = "pre")
-    docvars(pre, 'context') <- "pre"
-    docnames(pre) <- paste0(docnames(pre), ".pre")
+    if (split_context) {
+        pre <- corpus(x[,c("docname", "from", "to", "pre", "keyword")], text_field = "pre")
+        docvars(pre, "context") <- "pre"
+        docnames(pre) <- paste0(docnames(pre), ".pre")
+        
+        post <- corpus(x[,c("docname", "from", "to", "post", "keyword")], text_field = "post")
+        docvars(post, "context") <- "post"
+        docnames(post) <- paste0(docnames(post), ".post")
+        
+        result <- pre + post
+        if (!extract_keyword) docvars(result, "keyword") <- NULL
 
-    post <- corpus(x[,c("docname", "from", "to", "post", "keyword")], text_field = "post")
-    docvars(post, 'context') <- "post"
-    docnames(post) <- paste0(docnames(post), ".post")
+    } else {
+        result <- corpus(
+            apply(x[, c("pre", "keyword", "post")], 1, paste, collapse = " "),
+            docnames = paste0(x[["docname"]], ".L", x[["from"]])
+        )
+        if (extract_keyword) docvars(result, "keyword") <- x[["keyword"]]
+    }
 
-    result <- pre + post
+    # handle disassociated brackets, quotes, parens, etc
+    texts(result) <-
+        stri_replace_all_regex(texts(result), 
+                               "([\\b\\s][\\p{Pi}\\p{Ps}\"\'])\\s(\\S+)\\s([\\p{Pf}\\p{Pe}\"\'][\\b\\s])", 
+                               "$1$2$3")
+
+    # remove spaces before punctuation that should not have it
+    texts(result) <- stri_replace_all_regex(texts(result), "\\s([!%*?;:,.]{1})", "$1")
+    
     metacorpus(result, "source") <- 
         paste0("Corpus created from kwic(x, keywords = \"",
                paste(attr(x, "keywords"), collapse = ", "),
@@ -356,9 +380,7 @@ corpus.kwic <- function(x, ...) {
 #' @export
 corpus.Corpus <- function(x, metacorpus = NULL, compress = FALSE, ...) {
 
-    if (length(addedArgs <- list(...)))
-        warning("Argument", ifelse(length(addedArgs)>1, "s ", " "), 
-                names(addedArgs), " not used.", sep = "")
+    unused_dots(...)
 
     # special handling for VCorpus meta-data
     if (inherits(x, what = "VCorpus")) {
