@@ -1,9 +1,9 @@
-#' remove sentences based on their token lengths or a pattern match
+#' Remove sentences based on their token lengths or a pattern match
 #' 
 #' Removes sentences from a corpus or a character vector shorter than a 
 #' specified length.
 #' @param x \link{corpus} or character object whose sentences will be selected.
-#' @param what units of triming, \code{"sentences"} or \code{"paragraphs"}, or
+#' @param what units of trimming, \code{"sentences"} or \code{"paragraphs"}, or
 #'   \code{"documents"}
 #' @param min_ntoken,max_ntoken minimum and maximum lengths in word tokens 
 #'   (excluding punctuation)
@@ -28,14 +28,16 @@
 #' texts(corpus_trim(mycorp, exclude_pattern = "^PAGE \\d+"))
 #' 
 corpus_trim <- function(x, what = c("sentences", "paragraphs", "documents"),
-                        min_ntoken = 1, max_ntoken = NULL, exclude_pattern = NULL) {
+                        min_ntoken = 1, max_ntoken = NULL, 
+                        exclude_pattern = NULL) {
     UseMethod("corpus_trim")
 }
 
 #' @noRd
 #' @export
 corpus_trim.corpus <- function(x, what = c("sentences", "paragraphs", "documents"),
-                               min_ntoken = 1, max_ntoken = NULL, exclude_pattern = NULL) {
+                               min_ntoken = 1, max_ntoken = NULL, 
+                               exclude_pattern = NULL) {
     
     what <- match.arg(what)
     if (is.null(max_ntoken)) max_ntoken <- 1e10 
@@ -53,7 +55,8 @@ corpus_trim.corpus <- function(x, what = c("sentences", "paragraphs", "documents
     
     # exclude based on regular expression match
     if (!is.null(exclude_pattern)) {
-        temp <- corpus_subset(temp, !stri_detect_regex(texts(temp), exclude_pattern))
+        temp <- corpus_subset(temp, !stri_detect_regex(texts(temp), 
+                                                       exclude_pattern))
     }
     
     if (what != "documents") {
@@ -87,7 +90,7 @@ char_trim.character <- function(x, what = c("sentences", "paragraphs", "document
 }
 
 
-#' remove sentences based on their token lengths or a pattern match
+#' Remove sentences based on their token lengths or a pattern match
 #' 
 #' Removes sentences from a corpus or a character vector shorter than a 
 #' specified length.
@@ -103,14 +106,14 @@ char_trim.character <- function(x, what = c("sentences", "paragraphs", "document
 #'   a tokenized set of sentences if .  If the input was a corpus, then the all
 #'   docvars and metadata are preserved.  For documents whose sentences have
 #'   been removed entirely, a null string (\code{""}) will be returned.
-#' @note This function has been superceded by \code{\link{corpus_trim}}; use that
-#'   function instead.
+#' @note This function has been superceded by \code{\link{corpus_trim}}; use
+#'   that function instead.
 #' @export
 #' @keywords internal deprecated
 #' @examples
-#' txt <- c("PAGE 1. This is a single sentence.  Short sentence. Three word sentence.",
+#' txt <- c("PAGE 1. A single sentence.  Short sentence. Three word sentence.",
 #'          "PAGE 2. Very short! Shorter.",
-#'          "Very long sentence, with multiple parts, separated by commas.  PAGE 3.")
+#'          "Very long sentence, with three parts, separated by commas.  PAGE 3.")
 #' mycorp <- corpus(txt, docvars = data.frame(serial = 1:3))
 #' texts(mycorp)
 #' 
@@ -136,8 +139,9 @@ corpus_trimsentences.corpus <- function(x, min_length = 1, max_length = 10000,
     temp_sentences <- corpus_reshape(x, to = "sentences")
     
     # exclude based on lengths
-    docvars(temp_sentences, "ntok") <-  ntoken(temp_sentences, remove_punct = TRUE)
-    temp_sentences <- corpus_subset(temp_sentences, ntok >= min_length & ntok <= max_length)
+    docvars(temp_sentences, "ntok") <- ntoken(temp_sentences, remove_punct = TRUE)
+    temp_sentences <- 
+        corpus_subset(temp_sentences, ntok >= min_length & ntok <= max_length)
     docvars(temp_sentences, "ntok") <- NULL
     
     # exclude based on regular expression match
@@ -155,13 +159,14 @@ corpus_trimsentences.corpus <- function(x, min_length = 1, max_length = 10000,
 #' @examples
 #' char_trimsentences(txt, min_length = 3)
 #' char_trimsentences(txt, exclude_pattern = "sentence\\.")
-char_trimsentences <- function(x, min_length = 1, max_length = 10000, exclude_pattern = NULL) {
+char_trimsentences <- function(x, min_length = 1, max_length = 10000, 
+                               exclude_pattern = NULL) {
     UseMethod("char_trimsentences")
 }
 
 #' @noRd
 #' @export
-char_trimsentences.character <- function(x, min_length = 1, max_length = 10000, exclude_pattern = NULL) {
+char_trimsentences.character <- function(x, min_length = 1, max_length = 10000, 
+                                         exclude_pattern = NULL) {
     texts(corpus_trimsentences(corpus(x), min_length, max_length, exclude_pattern))
 }
-
